@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Math::Shape::Line;
-$Math::Shape::Line::VERSION = '0.14';
+$Math::Shape::Line::VERSION = '0.15';
 use 5.008;
 use Carp;
 use Math::Shape::Vector;
@@ -105,7 +105,7 @@ Math::Shape::Line - a 2d vector-based infinite line
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 METHODS
 
@@ -139,11 +139,11 @@ Boolean method that returns 1 if the line collides with another L<Math::Shape::V
 
 =head1 AUTHOR
 
-David Farrell <sillymoos@cpan.org>
+David Farrell <dfarrell@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by David Farrell.
+This software is copyright (c) 2015 by David Farrell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
