@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Math::Shape::OrientedRectangle;
-$Math::Shape::OrientedRectangle::VERSION = '0.14';
+$Math::Shape::OrientedRectangle::VERSION = '0.15';
 use 5.008;
 use Carp;
 use Math::Shape::Vector;
@@ -284,7 +284,7 @@ Math::Shape::OrientedRectangle - a 2d oriented rectangle
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 METHODS
 
@@ -330,11 +330,11 @@ Boolean method returns 1 if the OrientedRectangle collides with another L<Math::
 
 =head1 AUTHOR
 
-David Farrell <sillymoos@cpan.org>
+David Farrell <dfarrell@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by David Farrell.
+This software is copyright (c) 2015 by David Farrell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
