@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Math::Shape::Vector;
-$Math::Shape::Vector::VERSION = '0.14';
+$Math::Shape::Vector::VERSION = '0.15';
 use 5.008;
 use Carp;
 use Math::Shape::Utils;
@@ -256,6 +256,19 @@ sub distance
     }
 }
 
+use overload
+    '""' => \&stringify;
+
+sub stringify
+{
+    my $string = 'Vector ';
+    for (sort keys %{$_[0]})
+    {
+       $string .= "$_: $_[0]->{$_}, ";
+    }
+    substr $string, 0, -2;
+}
+
 
 1;
 
@@ -271,7 +284,7 @@ Math::Shape::Vector - A 2d vector library in cartesian space
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -467,11 +480,11 @@ The source code for this class was inspired by the code in Thomas Schwarzl's 2d
 
 =head1 AUTHOR
 
-David Farrell <sillymoos@cpan.org>
+David Farrell <dfarrell@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by David Farrell.
+This software is copyright (c) 2015 by David Farrell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
